[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- translate.tools.build_tmdb.Builder
- xml.dom.xmlbuilder.DOMImplementationLS
  - xml.dom.minidom.DOMImplementation
    - translate.misc.ourdom.DOMImplementation
- csv.Dialect: Describe an Excel dialect.
- translate.tools.pydiff.DirDiffer: generates diffs between directories
- translate.storage.directory.Directory: This class represents a directory.
- translate.storage.directory.Directory: This class represents a directory.
- xml.dom.xmlbuilder.DocumentLS: Mixin to create documents that conform to the load/save spec.
  - xml.dom.minidom.Document
    - translate.misc.ourdom.Document
- translate.misc.progressbar.DotsProgressBar: An ultra-simple progress indicator that just writes a dot for each action
- xml.dom.expatbuilder.ExpatBuilder: Document builder that uses Expat to build a ParsedXML.DOM document instance.
  - xml.dom.expatbuilder.ExpatBuilderNS: Document builder that supports namespaces.
    - translate.misc.ourdom.ExpatBuilderNS
- translate.tools.pydiff.FileDiffer: generates diffs between files
- translate.lang.ngram.Generate
- translate.storage.versioncontrol.GenericRevisionControlSystem: The super class for all version control classes.
  - translate.storage.versioncontrol.bzr.bzr: Class to manage items under revision control of bzr.
  - translate.storage.versioncontrol.cvs.cvs: Class to manage items under revision control of CVS.
  - translate.storage.versioncontrol.darcs.darcs: Class to manage items under revision control of darcs.
  - translate.storage.versioncontrol.git.git: Class to manage items under revision control of git.
  - translate.storage.versioncontrol.hg.hg: Class to manage items under revision control of mercurial.
  - translate.storage.versioncontrol.svn.svn: Class to manage items under revision control of Subversion.
- translate.tools.pogrep.GrepFilter
- optparse.HelpFormatter: Abstract base class for formatting option help.
  - translate.misc.optrecurse.ManHelpFormatter
- translate.search.lshtein.LevenshteinComparer
- translate.lang.ngram.NGram
- xml.dom.expatbuilder.Namespaces: Mix-in class for builders; adds support for namespaces.
  - xml.dom.expatbuilder.ExpatBuilderNS: Document builder that supports namespaces.
    - translate.misc.ourdom.ExpatBuilderNS
- translate.misc.progressbar.NoProgressBar: An invisible indicator that does nothing.
- xml.dom.Node: Class giving the NodeType constants.
  - xml.dom.minidom.Node
    - xml.dom.minidom.Document
      - translate.misc.ourdom.Document
    - xml.dom.minidom.Element
      - translate.misc.ourdom.Element
- optparse.Option: Instance attributes: _short_opts : [string] _long_opts : [string]
  - translate.misc.optrecurse.ManPageOption
- optparse.OptionContainer: Abstract base class.
  - optparse.OptionParser: Class attributes: standard_option_list : [Option] list of standard options that will be accepted by all instances of this parser class (intended to be overridden by subclasses).
    - translate.misc.optrecurse.RecursiveOptionParser: A specialized Option Parser for recursing through directories.
      - translate.convert.convert.ConvertOptionParser: a specialized Option Parser for convertor tools...
        - translate.convert.convert.ArchiveConvertOptionParser: ConvertOptionParser that can handle recursing into single archive files.
- translate.tools.pocompile.POCompile
- markupbase.ParserBase: Parser base class which provides some common support methods used by the SGML/HTML and XHTML parsers.
  - HTMLParser.HTMLParser: Find tags and other markup and call handler functions.
    - translate.storage.html.htmlfile
      - translate.storage.html.POHTMLParser
- translate.misc.progressbar.ProgressBar: A plain progress bar that doesn't know very much about output.
  - translate.misc.progressbar.HashProgressBar: A ProgressBar which knows how to go back to the beginning of the line.
    - translate.misc.progressbar.VerboseProgressBar
  - translate.misc.progressbar.MessageProgressBar: A ProgressBar that just writes out the messages without any progress display
- translate.storage.ts.QtTsParser
- translate.convert.convert.Replacer: an object that knows how to replace strings in files
- translate.storage.csvl10n.SimpleDictReader
- translate.misc.sparse.SimpleParser: this is a simple parser
- translate.storage.workflow.StateEnum: Only contains the constants for default states.
- translate.misc.stdiotell.StdIOWrapper
- translate.misc.wStringIO.StringIO
  - translate.storage.xpi.CatchPotentialOutput: catches output if there has been, before closing
  - translate.misc.wStringIO.CatchStringOutput: catches the output before it is closed and sends it to an onclose method
  - translate.storage.xpi.FixedStringIO
- ctypes.Structure
- ctypes.Structure
- ctypes.Structure
- translate.filters.checks.TeeChecker: A Checker that controls multiple checkers.
- translate.search.terminology.TerminologyComparer
- translate.misc.textwrap.TextWrapper: Object for wrapping/filling text.
- translate.storage.benchmark.TranslateBenchmarker: class to aid in benchmarking Translate Toolkit stores
- UserDict.UserDict
  - weakref.WeakValueDictionary: Mapping class that references values weakly.
    - translate.misc.lru.LRUCachingDict: Caching dictionary like object that discards the least recently used objects when number of cached items exceeds maxsize.
- translate.misc.xmlwrapper.XMLWrapper: simple wrapper for xml objects
- zipfile.ZipFile: Class with methods to open, read, write, close, list zip files.
  - translate.misc.zipfileext.ZipFileExt: a ZipFile that can handle replacing objects
    - translate.storage.xpi.ZipFileCatcher: a ZipFile that calls any methods its instructed to before closing (useful for catching stream output)
      - translate.storage.xpi.XpiFile
- translate.lang.ngram._NGram
- translate.convert.csv2po.csv2po: a class that takes translations from a .csv file and puts them in a .po file
- translate.convert.csv2tbx.csv2tbx: a class that takes translations from a .csv file and puts them in a .tbx file
- translate.convert.dtd2po.dtd2po
- translate.convert.html2po.html2po
- translate.convert.ical2po.ical2po: convert a iCal file to a .po file for handling the translation...
- translate.convert.ini2po.ini2po: convert a .ini file to a .po file for handling the translation...
- object: The most base type
  - exceptions.BaseException: Common base class for all exceptions
    - exceptions.Exception: Common base class for all non-exit exceptions.
      - translate.storage.projstore.FileExistsInProjectError
      - translate.storage.projstore.FileNotInProjectError
      - translate.filters.checks.FilterFailure: This exception signals that a Filter didn't pass, and gives an explanation or a comment
      - translate.storage.bundleprojstore.InvalidBundleError
      - translate.storage.tmdb.LanguageError
      - translate.misc.selector.MappingFileError
      - translate.storage.base.ParseError
      - translate.misc.selector.PathExpressionParserError
      - exceptions.StandardError: Base class for all standard Python exceptions that do not represent interpreter exiting.
        - exceptions.ValueError: Inappropriate argument value (of correct type).
          - translate.storage.placeables.strelem.ElementNotFoundError
          - translate.misc.sparse.ParserError: Intelligent parser error
      - translate.storage.workflow.StateNotInWorkflowError
      - translate.misc.typecheck.TypeCheckException
        - translate.misc.typecheck.TypeCheckError
      - translate.misc.typecheck.TypeSignatureError
      - translate.convert.factory.UnknownExtensionError
      - translate.convert.factory.UnsupportedConversionError
      - translate.storage.workflow.WorkflowError
        - translate.storage.workflow.InvalidStateObjectError
        - translate.storage.workflow.NoInitialStateError
        - translate.storage.workflow.TransitionError
      - translate.misc.typecheck._TC_Exception
        - translate.misc.typecheck._TC_AttrException
          - translate.misc.typecheck._TC_AttrError
          - translate.misc.typecheck._TC_MissingAttrError
        - translate.misc.typecheck._TC_ExactError
        - translate.misc.typecheck._TC_FunctionError
        - translate.misc.typecheck._TC_LengthError
        - translate.misc.typecheck._TC_NestedError
          - translate.misc.typecheck._TC_AttrError
          - translate.misc.typecheck._TC_DictError
            - translate.misc.typecheck._TC_KeyError
              - translate.misc.typecheck._TC_KeyValError
          - translate.misc.typecheck._TC_GeneratorError
          - translate.misc.typecheck._TC_IndexError
          - translate.misc.typecheck.mixins._TC_IterationError
          - translate.misc.typecheck._TC_XorError
        - translate.misc.typecheck._TC_TypeError
        - translate.misc.typecheck._TC_YieldCountError
      - translate.misc.typecheck._TS_Exception
        - translate.misc.typecheck._TS_ExtraKeywordError
        - translate.misc.typecheck._TS_ExtraPositionalError
        - translate.misc.typecheck._TS_MissingTypeError
        - translate.misc.typecheck._TS_TupleError
        - translate.misc.typecheck._TS_TwiceTypedError
  - translate.misc.selector.ByMethod: Base class for dispatching to method named by REQUEST_METHOD.
  - translate.storage.xpi.CatchPotentialOutput: catches output if there has been, before closing
  - translate.misc.wStringIO.CatchStringOutput: catches the output before it is closed and sends it to an onclose method
  - translate.storage.catkeys.CatkeysHeader: A catkeys translation memory header
  - translate.misc.typecheck.CheckType
    - translate.misc.typecheck.Any
    - translate.misc.typecheck.Class
    - translate.misc.typecheck.Dict
    - translate.misc.typecheck.Exact
    - translate.misc.typecheck.Function
    - translate.misc.typecheck.HasAttr
    - translate.misc.typecheck.IsCallable
    - translate.misc.typecheck.IsIterable
    - translate.misc.typecheck.Length
    - translate.misc.typecheck.List
      - translate.misc.typecheck.Tuple
    - translate.misc.typecheck.sets.Set
    - translate.misc.typecheck.Single
      - translate.misc.typecheck.Empty
    - translate.misc.typecheck.TypeVariables
    - translate.misc.typecheck.Typeclass
    - translate.misc.typecheck.YieldSeq
    - translate.misc.typecheck._Boolean
      - translate.misc.typecheck.And
      - translate.misc.typecheck.Or
        - translate.misc.typecheck.Not
      - translate.misc.typecheck.Xor
  - translate.filters.checks.CheckerConfig: object representing the configuration of a checker
  - translate.lang.common.Common: This class is the common parent class for all language classes.
    - translate.lang.af.af: This class represents Afrikaans.
    - translate.lang.am.am: This class represents Amharic.
    - translate.lang.ar.ar: This class represents Arabic.
    - translate.lang.bn.bn: This class represents Bengali.
    - translate.lang.code_or.code_or: This class represents Oriya.
    - translate.lang.de.de: This class represents German.
    - translate.lang.el.el: This class represents Greek.
    - translate.lang.es.es: This class represents Spanish.
    - translate.lang.fa.fa: This class represents Persian.
    - translate.lang.fi.fi: This class represents Finish.
    - translate.lang.fr.fr: This class represents French.
    - translate.lang.gu.gu: This class represents Gujarati.
    - translate.lang.he.he: This class represents Hebrew.
    - translate.lang.hi.hi: This class represents Hindi.
    - translate.lang.hy.hy: This class represents Armenian.
    - translate.lang.ja.ja: This class represents Japanese.
    - translate.lang.km.km: This class represents Khmer.
    - translate.lang.kn.kn: This class represents Kannada.
    - translate.lang.ko.ko: This class represents Korean.
    - translate.lang.ml.ml: This class represents Malayalam.
    - translate.lang.mr.mr: This class represents Marathi.
    - translate.lang.ne.ne: This class represents Nepali.
    - translate.lang.pa.pa: This class represents Punjabi.
    - translate.lang.si.si: This class represents Sinhala.
    - translate.lang.st.st: This class represents Southern Sotho.
    - translate.lang.sv.sv: This class represents Swedish.
    - translate.lang.ta.ta: This class represents Tamil.
    - translate.lang.te.te: This class represents Telugu.
    - translate.lang.th.th: This class represents Thai.
    - translate.lang.ug.ug: This class represents Uyghur.
    - translate.lang.ur.ur: This class represents Urdu.
    - translate.lang.vi.vi: This class represents Vietnamese.
    - translate.lang.zh.zh: This class represents Chinese.
  - translate.search.indexing.CommonIndexer.CommonDatabase: base class for indexing support
    - translate.search.indexing.XapianIndexer.XapianDatabase: interface to the xapian (http://xapian.org) indexer
  - translate.search.indexing.CommonIndexer.CommonEnquire: an enquire object contains the information about the result of a request
    - translate.search.indexing.XapianIndexer.XapianEnquire: interface to the xapian object for storing sets of matches
  - iniparse.config.ConfigNamespace
    - translate.misc.ini.INIConfig
    - translate.misc.ini.INISection
  - translate.convert.convert.ConvertOptionParser: a specialized Option Parser for convertor tools...
    - translate.convert.convert.ArchiveConvertOptionParser: ConvertOptionParser that can handle recursing into single archive files.
  - translate.convert.convert.ConvertOptionParser: a specialized Option Parser for convertor tools...
  - translate.storage.placeables.interfaces.Delimiter
    - translate.storage.placeables.base.It
      - translate.storage.placeables.xliff.It
    - translate.storage.placeables.base.X
      - translate.storage.placeables.xliff.X
  - translate.storage.properties.Dialect: Settings for the various behaviours in key=value files.
  - translate.storage.ini.Dialect: Base class for differentiating dialect options and functions
    - translate.storage.ini.DialectDefault
      - translate.storage.ini.DialectInno
  - translate.misc.selector.EnvironDispatcher: Dispatch based on list of rules.
  - translate.misc.typecheck.Fake_generator
  - translate.storage.statsdb.FileTotals
  - translate.misc.contextlib.GeneratorContextManager: Helper for @contextmanager decorator.
  - translate.tools.pogrep.GrepMatch: Just a small data structure that represents a search match.
  - translate.storage.xml_extract.extract.IdMaker
  - translate.lang.identify.LanguageIdentifier
  - translate.misc.ini.LineContainer
  - translate.misc.ini.LineType
    - translate.misc.ini.CommentLine
    - translate.misc.ini.ContinuationLine
    - translate.misc.ini.EmptyLine
    - translate.misc.ini.OptionLine
    - translate.misc.ini.SectionLine
  - translate.misc.optrecurse.ManPageOption
  - translate.misc.selector.MiddlewareComposer: Compose middleware based on list of rules.
  - translate.misc.selector.Naked: Naked object style dispatch base class.
  - translate.storage.placeables.interfaces.PairedDelimiter
    - translate.storage.placeables.base.Bpt
      - translate.storage.placeables.xliff.Bpt
    - translate.storage.placeables.base.Bx
      - translate.storage.placeables.xliff.Bx
    - translate.storage.placeables.base.Ept
      - translate.storage.placeables.xliff.Ept
    - translate.storage.placeables.base.Ex
      - translate.storage.placeables.xliff.Ex
  - translate.storage.poparser.ParseState
  - translate.storage.xml_extract.extract.ParseState: Maintain constants and variables used during the walking of a DOM tree (via the function apply).
  - translate.storage.symbian.ParseState
  - translate.storage.project.Project: Manages a project store as well as the processes involved in a project workflow.
  - translate.storage.projstore.ProjectStore: Basic project file container.
    - translate.storage.bundleprojstore.BundleProjectStore: Represents a translate project bundle (zip archive).
  - xapian.Query: Class representing a query.
  - translate.misc.optrecurse.RecursiveOptionParser: A specialized Option Parser for recursing through directories.
    - translate.convert.convert.ConvertOptionParser: a specialized Option Parser for convertor tools...
      - translate.convert.convert.ArchiveConvertOptionParser: ConvertOptionParser that can handle recursing into single archive files.
  - translate.misc.selector.Selector: WSGI middleware for URL paths and HTTP method based delegation.
  - translate.misc.selector.SimpleParser: Callable to turn path expressions into regexes with named groups.
  - translate.storage.workflow.State
    - translate.storage.workflow.UnitState
  - translate.storage.statistics.Statistics: Manages statistics for storage objects.
  - translate.storage.statsdb.StatsCache: An object instantiated as a singleton for each statsfile that provides access to the database cache from a pool of StatsCache objects.
  - translate.storage.placeables.strelem.StringElem: This class represents a sub-tree of a string parsed into a rich structure.
    - translate.storage.placeables.interfaces.InvisiblePlaceable
    - translate.storage.placeables.interfaces.MaskingPlaceable
      - translate.storage.placeables.base.Bpt
        - translate.storage.placeables.xliff.Bpt
      - translate.storage.placeables.base.Ept
        - translate.storage.placeables.xliff.Ept
      - translate.storage.placeables.base.It
        - translate.storage.placeables.xliff.It
      - translate.storage.placeables.base.Ph
        - translate.storage.placeables.general.CamelCasePlaceable: Placeable handling camel case strings.
        - translate.storage.placeables.general.CapsPlaceable: Placeable handling long all-caps strings.
        - translate.storage.placeables.general.EmailPlaceable: Placeable handling emails.
        - translate.storage.placeables.general.FilePlaceable: Placeable handling file locations.
        - translate.storage.placeables.general.FormattingPlaceable: Placeable representing string formatting variables.
        - translate.storage.placeables.general.JavaMessageFormatPlaceable: Placeable representing a Java MessageFormat formatting variable.
        - translate.storage.placeables.general.NewlinePlaceable: Matches new-lines.
        - translate.storage.placeables.general.NumberPlaceable: Placeable for numbers.
        - translate.storage.placeables.general.OptionPlaceable: Placeble handling command line options e.g.
        - translate.storage.placeables.xliff.Ph
        - translate.storage.placeables.general.PunctuationPlaceable: Placeable handling punctuation.
        - translate.storage.placeables.general.PythonFormattingPlaceable: Placeable representing a Python string formatting variable.
        - translate.storage.placeables.general.QtFormattingPlaceable: Placeable representing a Qt string formatting variable.
        - translate.storage.placeables.general.SpacesPlaceable: Placeable handling unusual spaces in strings.
        - translate.storage.placeables.terminology.TerminologyPlaceable: Terminology distinguished from the rest of a string by being a placeable.
        - translate.storage.placeables.general.UrlPlaceable: Placeable handling URI.
        - translate.storage.placeables.general.XMLEntityPlaceable: Placeable handling XML entities (`&xxxxx;`-style entities).
        - translate.storage.placeables.general.XMLTagPlaceable: Placeable handling XML tags.
    - translate.storage.placeables.interfaces.ReplacementPlaceable
      - translate.storage.placeables.base.Bx
        - translate.storage.placeables.xliff.Bx
      - translate.storage.placeables.base.Ex
        - translate.storage.placeables.xliff.Ex
      - translate.storage.placeables.base.G
        - translate.storage.placeables.general.AltAttrPlaceable: Placeable for the "alt=..." attributes inside XML tags.
        - translate.storage.placeables.xliff.G
      - translate.storage.placeables.base.X
        - translate.storage.placeables.xliff.X
    - translate.storage.placeables.interfaces.SubflowPlaceable
      - translate.storage.placeables.base.Sub
        - translate.storage.placeables.xliff.Sub
    - translate.storage.placeables.xliff.UnknownXML: Placeable for unrecognized or umimplemented XML nodes.
  - translate.storage.tmdb.TMDB
  - translate.services.tmserver.TMServer: A RESTful JSON TM server.
  - translate.tools.poterminology.TerminologyExtractor
  - translate.storage.xml_extract.extract.Translatable: A node corresponds to a translatable element.
  - translate.storage.base.TranslationStore: Base class for stores for multiple translation units of type UnitClass.
    - translate.storage.lisa.LISAfile: A class representing a file store for one of the LISA file formats.
    - translate.storage.tiki.TikiStore: Represents a tiki language.php file.
    - translate.storage.txt.TxtFile: This class represents a text file, made up of txtunits
    - translate.storage.dtd.dtdfile: this class represents a .dtd file, made up of dtdunits
    - translate.storage.html.htmlfile
      - translate.storage.html.POHTMLParser
    - translate.storage.ical.icalfile: An ical file
    - translate.storage.ini.inifile: An INI file
    - translate.storage.php.phpfile: This class represents a PHP file, made up of phpunits
    - translate.storage.rc.rcfile: This class represents a .rc file, made up of rcunits.
  - translate.storage.base.TranslationUnit: Base class for translation units.
    - translate.storage.lisa.LISAunit: A single unit in the file.
    - translate.storage.tiki.TikiUnit: A tiki unit entry.
    - translate.storage.txt.TxtUnit: This class represents a block of text from a text file
    - translate.storage.dtd.dtdunit: this class represents an entity definition from a dtd file (and possibly associated comments)
    - translate.storage.html.htmlunit: A unit of translatable/localisable HTML content
    - translate.storage.ical.icalunit: An ical entry that is translatable
    - translate.storage.ini.iniunit: A INI file entry
    - translate.storage.php.phpunit: a unit of a PHP file i.e.
    - translate.storage.rc.rcunit: A unit of an rc file
  - translate.filters.checks.UnitChecker: Parent Checker class which does the checking based on functions available in derived classes.
  - translate.storage.wordfast.WordfastHeader: A wordfast translation memory header
  - translate.storage.wordfast.WordfastTime: Manages time stamps in the Wordfast format of YYYYMMDD~hhmmss
  - translate.storage.workflow.Workflow
  - translate.storage.xml_extract.xpath_breadcrumb.XPathBreadcrumb: A class which is used to build XPath-like paths as a DOM tree is walked.
  - translate.storage.xml_extract.unit_tree.XPathTree
  - translate.storage.xml_name.XmlNamer: Initialize me with a DOM node or a DOM document node (the toplevel node you get when parsing an XML file).
  - translate.storage.xml_name.XmlNamespace
  - translate.storage.xpi.ZipFileCatcher: a ZipFile that calls any methods its instructed to before closing (useful for catching stream output)
    - translate.storage.xpi.XpiFile
  - translate.misc.zipfileext.ZipFileExt: a ZipFile that can handle replacing objects
    - translate.storage.xpi.ZipFileCatcher: a ZipFile that calls any methods its instructed to before closing (useful for catching stream output)
      - translate.storage.xpi.XpiFile
  - translate.misc.typecheck.mixins._UnorderedIteratorMixin
  - basestring: Type basestring cannot be instantiated; it is the base for str and unicode.
    - unicode: unicode(string [, encoding[, errors]]) -> object
      - translate.misc.autoencode.autoencode
        - translate.misc.multistring.multistring
  - translate.misc.contextlib.closing: Context to automatically close something at the end of a block.
  - dict: dict() -> new empty dictionary.
    - translate.misc.dictutils.cidict
    - translate.misc.dictutils.ordereddict: a dictionary which remembers its keys in the order in which they were given
    - translate.storage.oo.unormalizechar
  - translate.search.match.matcher: A class that will do matching and store configuration for the matching process
  - translate.storage.oo.ooline: this represents one line, one translation in an .oo file
  - translate.storage.poheader.poheader: This class implements functionality for manipulation of po file headers.
  - translate.storage.poheader.poheader: This class implements functionality for manipulation of po file headers.
- translate.convert.oo2po.oo2po
- translate.convert.oo2xliff.oo2xliff
- translate.storage.oo.oofile: this represents an entire .oo file
- translate.convert.xliff2oo.oofilteroptions
- translate.convert.po2oo.oofilteroptions
- translate.storage.oo.oomultifile: this takes a huge GSI file and represents it as multiple smaller files...
- translate.storage.oo.oounit: this represents a number of translations of a resource
- translate.convert.php2po.php2po: convert a .php file to a .po file for handling the translation...
- translate.tools.phppo2pypo.phppo2pypo
- translate.convert.po2csv.po2csv
- translate.convert.po2dtd.po2dtd: this is a convertor class that creates a new dtd file based on a po file without a template
- translate.convert.po2html.po2html: po2html can take a po file and generate html.
- translate.convert.po2web2py.po2pydict
- translate.convert.po2tiki.po2tiki
- translate.convert.po2tmx.po2tmx
- translate.convert.po2ts.po2ts
- translate.convert.po2txt.po2txt: po2txt can take a po file and generate txt.
- translate.convert.po2wordfast.po2wordfast
- translate.convert.po2xliff.po2xliff
- translate.filters.pofilter.pocheckfilter
- translate.filters.pofilter.pocheckfilter
- translate.tools.podebug.podebug
- translate.convert.poreplace.poreplace
- translate.convert.prop2po.prop2po: convert a .properties file to a .po file for handling the translation.
- translate.tools.pypo2phppo.pypo2phppo
- translate.convert.rc2po.rc2po: Convert a .rc file to a .po file for handling the translation.
- translate.convert.po2dtd.redtd: this is a convertor class that creates a new dtd based on a template using translations in a po
- translate.convert.po2ical.reical
- translate.convert.po2ini.reini
- translate.convert.po2oo.reoo
- translate.convert.xliff2oo.reoo
- translate.convert.po2php.rephp
- translate.convert.po2prop.reprop
- translate.convert.po2rc.rerc
- translate.convert.po2sub.resub
- translate.tools.posegment.segment
- translate.tools.pocount.summarizer
- translate.convert.tiki2po.tiki2po
- translate.convert.po2tmx.tmxmultifile
- translate.convert.ts2po.ts2po
- translate.convert.txt2po.txt2po
- translate.convert.web2py2po.web2py2po
- translate.convert.po2wordfast.wfmultifile
- translate.convert.xliff2po.xliff2po